/**
 * Copyright 2018 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const gulp = require('gulp');
const browserSync = require('browser-sync');
const workboxBuild = require('workbox-build');

// Inject a precache manifest into the service worker
const buildSw = () => {
  return workboxBuild.injectManifest({
    swSrc: 'src/js/sw.js',
    swDest: 'src/sw.js',
    globDirectory: 'src',
    globPatterns: [
      'index.html',
      'favicon.ico',
      'css\/*.css',
			'js\/*.js',
			'images\/*.jpg',
      'images\/**\/*.png',
      'images\/**\/*.svg'
    ]
  }).then(resources => {
    console.log(`Injected ${resources.count} resources for precaching, ` +
        `totaling ${resources.size} bytes.`);
  }).catch(err => {
    console.log('Uh oh 😬', err);
  });
}
gulp.task('build-sw', buildSw);

// Build the app, run a local dev server, and rebuild on "src" file changes
const browserSyncOptions = {
  server: 'src',
  port: 8080,
  open: false
};

const serve = gulp.series('build-sw', () => {
  browserSync.init(browserSyncOptions);
  gulp.watch([
		'src/**/*',
		'!src/sw.js'
	], buildSw).on('change', browserSync.reload);
});
gulp.task('serve', serve);

// Set the default task to "serve"
gulp.task('default', serve);
